@@ -11,7 +11,7 @@ pub struct Page {
 
 impl Page {
 
-	pub fn from_file(&self, path: &Path) -> Result<Self> {
+	pub fn from_file(path: &Path) -> Result<Self> {
 
 		use std::fs::read_to_string;
 
